#ifndef NT2_CORE_INCLUDE_FUNCTIONS_TRANSFORM_HPP_INCLUDED
#define NT2_CORE_INCLUDE_FUNCTIONS_TRANSFORM_HPP_INCLUDED

#include <nt2/core/functions/transform.hpp>
#include <nt2/core/functions/expr/transform.hpp>
#include <nt2/core/functions/shared_memory/transform.hpp>
#include <nt2/core/functions/simd/transform.hpp>

#endif
